<?php
header("Access-Control-Allow-Origin: *");
header('Content-Type: application/json; charset=utf-8');
require_once('../../../wp-load.php');

// Verifica se o token foi enviado e se é válido
if ($_POST['token'] !== get_option('premiumjornalistic_api_token')) {
    die(json_encode(['reponse' => 'error', 'message' => 'Token inválido']));
}

// Obtém os dados enviados via POST
$action = $_POST['action'];

// Função para baixar e anexar a imagem ao post
function baixar_e_anexar_imagem($image_url, $post_id) {
    require_once(ABSPATH . 'wp-admin/includes/file.php');
    require_once(ABSPATH . 'wp-admin/includes/media.php');
    require_once(ABSPATH . 'wp-admin/includes/image.php');

    // Baixar a imagem
    $temp_file = download_url($image_url);

    // Verificar se houve erro no download
    if (is_wp_error($temp_file)) {
        return false;
    }

    // Definir um nome único para a imagem
    $image_name = basename($image_url);

    // Preparar array de arquivo para o upload
    $file = array(
        'name'     => $image_name,
        'type'     => mime_content_type($temp_file),
        'tmp_name' => $temp_file,
        'error'    => 0,
        'size'     => filesize($temp_file),
    );

    // Fazer o upload da imagem
    $upload_id = media_handle_sideload($file, $post_id);

    // Verificar se o upload foi bem-sucedido
    if (is_wp_error($upload_id)) {
        @unlink($temp_file);  // Excluir o arquivo temporário se o upload falhar
        return false;
    }

    return $upload_id;  // Retorna o ID do anexo da imagem
}

// Função para baixar e anexar o áudio ao post
function baixar_e_anexar_audio($audio_url, $post_id) {
    require_once(ABSPATH . 'wp-admin/includes/file.php');
    require_once(ABSPATH . 'wp-admin/includes/media.php');

    // Baixar o áudio
    $temp_file = download_url($audio_url);

    // Verificar se houve erro no download
    if (is_wp_error($temp_file)) {
        return false;
    }

    // Definir um nome único para o áudio
    $audio_name = basename($audio_url);

    // Preparar array de arquivo para o upload
    $file = array(
        'name'     => $audio_name,
        'type'     => 'audio/mpeg', // Tipo MIME explícito para .mp3
        'tmp_name' => $temp_file,
        'error'    => 0,
        'size'     => filesize($temp_file),
    );

    // Fazer o upload do áudio
    $upload_id = media_handle_sideload($file, $post_id);

    // Verificar se o upload foi bem-sucedido
    if (is_wp_error($upload_id)) {
        @unlink($temp_file);  // Excluir o arquivo temporário se o upload falhar
        return false;
    }

    return $upload_id;  // Retorna o ID do anexo do áudio
}


function get_category_hierarchy($parent_id = 0) {
    // Busca as categorias com base no ID do pai
    $categories = get_categories(array(
        'hide_empty' => false, // Mostrar todas as categorias, incluindo as que não têm posts
        'parent' => $parent_id, // Filtra pelas categorias que são filhas do ID passado
    ));
    
    $cats_array = array();
    
    // Percorre cada categoria
    foreach ($categories as $category) {
        // Adiciona a categoria atual ao array, junto com suas filhas
        $cats_array[] = array(
            'id' => $category->term_id,
            'name' => $category->name,
            'slug' => $category->slug,
            'children' => get_category_hierarchy($category->term_id) // Chama recursivamente para pegar as categorias filhas
        );
    }
    
    return $cats_array;
}
if($action=='plugins'){
	//listar plugins
}
if($action=='post-manager'){
    $titulo = $_POST['titulo'];
	$mt = $_POST['mt'];
	$post_id = $_POST['post_id'];
    $conteudo_html = $_POST['conteudo_html'];
    $status = $_POST['status'];
    $category = $_POST['category'];
    $user_id = $_POST['user_id'];
    $post_date = $_POST['date'];
    $uuid = $_POST['uuid'];
    
    $args_post = array(
    	'posts_per_page'  => 1,
    	'offset'      => 0,
    	'orderby'     => 'date',
    	'order'      => 'DESC',
    	'include'     => '',
    	'exclude'     => '',
    	'post_type'    => array('post'),
    	'post_mime_type'  => '',
    	'post_parent'   => '',
    	'author_name'	  => '',
    	'post_status'   => array('publish','draft','future', 'pending'),
    	'suppress_filters' => true,
    	'fields'      => '',
    );
    
    $args_post['meta_query'] = array(
    	array('key' => 'uuid','value' => $uuid,'compare' => '='),
    );
    
    $get_posts = get_posts( $args_post );
    if(count($get_posts)>0){
        $post_id = $get_posts[0]->ID;
        $post_status = $get_posts[0]->post_status;
        $permalink = get_permalink($post_id);
        echo json_encode(['reponse' => 'already_added', 'post_id' => $post_id, 'post_status' => $post_status, 'permalink' => $permalink]);
    }else{
        $category = get_category_by_slug($category);
    
        $timezone = get_option('timezone_string');
        date_default_timezone_set($timezone);
        
        if ($post_date == 'now') {
            $post_date = date('Y-m-d H:i:s');
        } else {
            $post_date = date('Y-m-d H:i:s', strtotime($post_date));
        }
        
        $post_date_gmt = get_gmt_from_date($post_date);
		
		$args_insert_post = array(
            'post_title'    => $titulo,
            'post_content'  => $conteudo_html,
            'post_status'   => $status,
            'post_type'     => 'post',
            'post_date'     => $post_date,
            'post_date_gmt' => $post_date_gmt,
            'post_author'   => $user_id,
            'post_category' => array($category->term_id), // associa a categoria
        );
		
		if($mt==1){
			// Inserir o post como notícia
			$post_id = wp_insert_post($args_insert_post);
		} else if($mt==2){
			wp_delete_post( $post_id, true );
			echo json_encode(['reponse' => 'deleted', 'post_id' => 0, 'post_status' => '', 'permalink' => '']);
			die();
		} else if($mt==2){
			// Atualiza o post
			wp_update_post( $args_insert_post );
		}
        
        // Verificar se houve erro ao inserir o post
        if (is_wp_error($post_id)) {
            die(json_encode(['reponse' => 'error', 'message' => 'Falha ao cadastrar a notícia: ' . $post_id->get_error_message()]));
        }
        
        
        // Processar a imagem de thumbnail (capa)
        if (isset($_POST['thumbnail']['src'])) {
            $thumbnail_url = esc_url_raw($_POST['thumbnail']['src']);
            
            if (is_numeric($thumbnail_url)) {
                if ($thumbnail_url==0) {
                    delete_post_thumbnail($post_id);
                }else{
                    set_post_thumbnail($post_id, $thumbnail_url);
                }
            }else{
                $thumbnail_alt = $_POST['thumbnail']['alt'];
                $thumbnail_id = baixar_e_anexar_imagem($thumbnail_url, $post_id);
                if ($thumbnail_id) {
                    // Define como imagem destacada (thumbnail)
                    set_post_thumbnail($post_id, $thumbnail_id);
                    
                    // Adiciona o atributo alt à imagem destacada (thumbnail)
                    if (!empty($thumbnail_alt)) {
                        update_post_meta($thumbnail_id, '_wp_attachment_image_alt', $thumbnail_alt);
                    }else{
                        update_post_meta($thumbnail_id, '_wp_attachment_image_alt', "Reprodução / Internet");
                    }
                } else {
                    error_log('Falha ao baixar e anexar a imagem de thumbnail.');
                }
            }
        }
        
        $conteudo_html = stripslashes($conteudo_html);
        
        // Processar imagens internas do conteúdo HTML
        //preg_match_all('/<img[^>]+src="([^">]+)"[^>]*alt="([^">]*)"/i', $conteudo_html, $matches);
        preg_match_all('/<img[^>]+src=["\']([^"\']+)["\'][^>]*>/i', $conteudo_html, $matches);
        if (!empty($matches[1])) {
            foreach ($matches[1] as $index => $img_url) {
                // Se o alt estiver vazio, define "Reprodução / Internet" como valor padrão
                $img_alt = !empty($matches[2][$index]) ? $matches[2][$index] : 'Reprodução / Internet'; 
                $img_id = baixar_e_anexar_imagem($img_url, $post_id);
                if ($img_id) {
                    $img_src = wp_get_attachment_url($img_id);
                    $img_alt = esc_attr($img_alt); // Sanitiza o atributo alt
                    $conteudo_html = str_replace($img_url, $img_src, $conteudo_html);  // Substituir URL da imagem no conteúdo
                    $conteudo_html = str_replace('alt="'.$img_alt.'"', 'alt="'.$img_alt.'"', $conteudo_html); // Insere o alt na nova imagem
                }
            }
            // Atualizar o conteúdo com as novas URLs das imagens e alts
            wp_update_post(array(
                'ID' => $post_id,
                'post_content' => wp_kses_post($conteudo_html),
            ));
        }
        
        //add $uuid
        update_post_meta($post_id, 'uuid', $uuid);
            
        // Adicionar campos personalizados (custom fields) se fornecidos
        if (isset($_POST['custom_fields']) && count($_POST['custom_fields']) > 0) {
            foreach ($_POST['custom_fields'] as $field) {
                $key = $field['key'];
                $value = $field['value'];
                update_post_meta($post_id, $key, $value);
            }
        }
        
        // Adicionar palavras-chave (tags) se fornecidas
        if (isset($_POST['keywords']) && !empty($_POST['keywords'])) {
            wp_set_post_tags($post_id, explode(',', $_POST['keywords']));
        }
		
		 // Verificar se um URL de áudio foi enviado
		if (isset($_POST['audio']) && !empty($_POST['audio'])) {
			$audio = esc_url_raw($_POST['audio']);
			$audio_id = baixar_e_anexar_audio($audio,$post_id);
			// Salva o URL do áudio no campo personalizado do post
			$audio_url = wp_get_attachment_url($audio_id);
			update_post_meta($post_id, 'premiumjornalistic_audio_url', $audio_url);
		}
        
        $permalink = get_permalink($post_id);
        echo json_encode(['reponse' => 'added', 'post_id' => $post_id, 'post_status' => $status, 'permalink' => $permalink]);
    }
}else if($action=='get-cats'){
    // Crie o array de categorias começando pelas principais (parent_id = 0)
    $cats_array = get_category_hierarchy();
    
    // Retorne a resposta JSON
    echo json_encode(['response' => 'success', 'cats' => $cats_array]);

}else if($action=='check-publish'){
    
    $uuid_array = $_POST['uuids'];  // Supondo que você está enviando um array de UUIDs

    $args_post = array(
        'posts_per_page'  => 100,  // Se você quer pegar todos os posts correspondentes
        'offset'          => 0,
        'orderby'         => 'date',
        'order'           => 'DESC',
        'post_type'       => array('post'),
        'post_status'     => array('publish', 'draft', 'future', 'pending'),
        'suppress_filters' => true,
        'fields'          => '', 
    );
    
    $args_post['meta_query'] = array(
        array(
            'key'     => 'uuid',
            'value'   => $uuid_array,  // Aqui passamos o array de UUIDs
            'compare' => 'IN',         // Compara com qualquer um dos valores no array
        ),
    );
    
    $get_posts = get_posts($args_post);
    
    if(count($get_posts) > 0){
        $response = [];
        foreach($get_posts as $post){
            $post_id = $post->ID;
            $post_status = $post->post_status;
            $permalink = get_permalink($post_id);
            $post_uuid = get_post_meta($post_id,'uuid',true);
            $response[] = ['post_id' => $post_id, 'post_status' => $post_status, 'permalink' => $permalink, 'post_uuid' => $post_uuid];
        }
        echo json_encode(['response' => 'success', 'posts' => $response]);
    } else {
        echo json_encode(['response' => 'no_posts_found']);
    }


}else{
    die(json_encode(['reponse' => 'error', 'message' => 'Action inválido']));
}

