<?php
/*
Plugin Name: Premium Jornalistic
Description: Feito por jornalistas, para jornalistas!
Version: 10.8
Author: Premium Jornalistic
*/

// Função para gerar token de API ao ativar o plugin
function gerar_token_api() {
    $token = bin2hex(random_bytes(32));
    update_option('premiumjornalistic_api_token', $token);
}
register_activation_hook(__FILE__, 'gerar_token_api');

// Função para adicionar menu do plugin
function premiumjornalistic_add_admin_menu() {
    add_menu_page(
        'Configurações do Plugin Premium Jornalistic',
        'Premium Jornalistic',
        'manage_options',
        'premiumjornalistic_settings',
        'premiumjornalistic_settings_page'
    );
}
add_action('admin_menu', 'premiumjornalistic_add_admin_menu');

// Função para gerar um novo token manualmente sem redirecionamento
function premiumjornalistic_gerar_novo_token_sem_redirect() {
    if (!current_user_can('manage_options')) {
        wp_die('Você não tem permissão para realizar esta ação.');
    }

    $token = bin2hex(random_bytes(32));
    update_option('premiumjornalistic_api_token', $token);
    return true; // Sinaliza que o token foi gerado
}

// Função para exibir a página de configurações
function premiumjornalistic_settings_page() {
    $token = get_option('premiumjornalistic_api_token');
    $status_message = '';

    // Verificar se o formulário de áudios foi enviado
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['mostrar_audios'])) {
        update_option('premiumjornalistic_mostrar_audios', sanitize_text_field($_POST['mostrar_audios']));
        $status_message = 'Configuração de áudios atualizada com sucesso!';
    }

    // Verificar se o botão para gerar novo token foi clicado
    if (isset($_POST['gerar_novo_token'])) {
        $token_gerado = premiumjornalistic_gerar_novo_token_sem_redirect();
        if ($token_gerado) {
            $status_message = 'Um novo token foi gerado com sucesso!';
            $token = get_option('premiumjornalistic_api_token'); // Atualizar token exibido
        }
    }

    $mostrar_audios = get_option('premiumjornalistic_mostrar_audios', 'sim'); // Padrão 'sim'

    ?>
    <div class="wrap">
        <h1>Configurações do Plugin Premium Jornalistic</h1>

        <?php if ($status_message): ?>
            <div class="notice notice-success is-dismissible">
                <p><?php echo esc_html($status_message); ?></p>
            </div>
        <?php endif; ?>

        <h2>Configurações</h2>

        <!-- Formulário para salvar configurações de áudio -->
        <form method="post" action="">
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Mostrar áudios nos posts?</th>
                    <td>
                        <label><input type="radio" name="mostrar_audios" value="sim" <?php checked($mostrar_audios, 'sim'); ?>> Sim</label><br>
                        <label><input type="radio" name="mostrar_audios" value="não" <?php checked($mostrar_audios, 'não'); ?>> Não</label>
                    </td>
                </tr>
            </table>
            <p class="submit">
                <input type="submit" class="button button-primary" value="Salvar alterações">
            </p>
        </form>

        <h2>Token de API</h2>
        <!-- Exibir token de API -->
        <pre id="api-token" style="background: #f7f7f7; padding: 10px; border-radius: 5px;"><?php echo esc_html($token); ?></pre>
        <button class="button button-secondary" id="copiar-token">Copiar Token</button><br><br>

        <!-- Formulário para gerar novo token -->
        <form method="post" action="">
            <input type="hidden" name="gerar_novo_token" value="1">
            <button type="submit" class="button button-primary">Gerar Novo Token</button>
        </form>
    </div>

    <script>
        document.getElementById('copiar-token').addEventListener('click', function() {
            var token = document.getElementById('api-token').innerText;
            navigator.clipboard.writeText(token).then(function() {
                alert('Token copiado para a área de transferência!');
            }, function(err) {
                alert('Erro ao copiar o token: ' + err);
            });
        });
    </script>
    <?php
}

// Função para inserir o player de áudio no topo do conteúdo
function premiumjornalistic_inserir_audio_no_post($content) {
    $mostrar_audios = get_option('premiumjornalistic_mostrar_audios', 'sim');

    if ($mostrar_audios === 'sim') {
        $audio_url = get_post_meta(get_the_ID(), 'premiumjornalistic_audio_url', true);
        if ($audio_url) {
            $audio_player = '<div class="post-audio-player"><audio controls> <source src="' . esc_url($audio_url) . '" type="audio/mp3"> </audio></div>';
            $content = $audio_player . $content; // Adiciona o player no topo
        }
    }
    return $content;
}
add_filter('the_content', 'premiumjornalistic_inserir_audio_no_post', 9999);
?>
